@@ -4,7 +4,7 @@
 # Based on yamas v0.9 by comaX for pcsci3ence.info
 
 #Version information
-version=0.9.8
+version=0.9.9
 
 # device variables
 pathLog=/home/user/yamas
@@ -102,8 +102,8 @@ dep() {
      echo 0 >> ./test.txt
    fi
 
-   echo -en "\t python-pyopenssl"
-   if dpkg -l | grep python-pyopenssl 1>/dev/null; then 
+   echo -en "\t python-openssl"
+   if dpkg -l | grep python-openssl 1>/dev/null; then 
      echo -e "\t\033[32m[Success]\033[m"
    else 
      echo -e "\t\033[31m[Failed!]\033[m"
